@@ -24,6 +24,14 @@ class IngressAdapter:
     1. Adapter -> Ingress guid -> Transformation -> Egress guid
     2. Adapter -> Egress guid (no transformation needed)
 
+    IngressAdapter responsibilities:
+    - The adapter can first assume the data is successfully ingested to ingress/egress if it receives a 201 code.
+      This is handled by the IngressAdapter by calling save_state after successful upload.
+      The IngressAdapter needs to implement the save_state method, where it will save the state for next batch/run -
+      assuming the current batch/run was successfully updated.
+      If the IngressAdapter does not use a state (it uploads all data every time) then save_state should still
+      be implement have no side effect.
+
     General note:
     The IngressAdapter handles the normal case where each run of the adapter will generate one file in a
     Ingress guid or Egress guid (dependent on case 1 or 2).
@@ -64,6 +72,13 @@ class IngressAdapter:
         """
         raise NotImplementedError
 
+    @abc.abstractmethod
+    def save_state(self) -> Optional[bytes]:
+        """
+        Save the state for next run. This method is first called after successful upload.
+        """
+        raise NotImplementedError
+
     @abc.abstractmethod
     def get_filename(self) -> str:
         """
@@ -103,6 +118,7 @@ class IngressAdapter:
 
         try:
             self.ingress.upload_json_file(file, schema_validate)
+            self.save_state()
         except Exception as error:  # pylint: disable=broad-except
             logger.error('Exception occurred while running upload_json_data: %s', str(error))
             sys.exit(-1)
@@ -122,6 +138,7 @@ class IngressAdapter:
 
         try:
             self.ingress.upload_file(file)
+            self.save_state()
         except Exception as error:  # pylint: disable=broad-except
             logger.error('Exception occurred while running upload_data: %s', str(error))
             sys.exit(-1)
